# Commands

`pangeo-forge-runner` supports various commands that
can be configured via traitlets.

## `expand-meta`

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.commands.expand_meta.ExpandMeta
```

## `bake`

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.commands.bake.Bake
```
